@@ -15,9 +15,9 @@ import logging
 import re
 import sys
 
+import yaml
 from configparser import NoSectionError
 
-import yaml
 from pcluster.config.iam_policy_rules import AWSBatchFullAccessInclusionRule, CloudWatchAgentServerPolicyInclusionRule
 from pcluster.config.resource_map import ResourceMap
 from pcluster.config.update_policy import UpdatePolicy
@@ -888,6 +888,15 @@ class ClusterConfigMetadataParam(JsonParam):
         LOGGER.debug("Automatic labels generated: {0}".format(str(section_labels)))
         return self.__section_resources.resources(section_key)
 
+    def to_file(self, config_parser, write_defaults=False):
+        """Ensure cluster_config_metadata_param is not exposed in the config file."""
+        LOGGER.debug("Ensuring cluster_config_metadata_param parameter is not written to configuration file.")
+        section_name = get_file_section_name(self.section_key, self.section_label)
+        try:
+            config_parser.remove_option(section_name, self.key)
+        except NoSectionError:
+            pass
+
 
 class ArchitectureParam(Param):
     """
@@ -911,6 +920,15 @@ class ArchitectureParam(Param):
 
         return self
 
+    def to_file(self, config_parser, write_defaults=False):
+        """Do nothing because architecture is not exposed in the config file."""
+        LOGGER.debug("Ensuring architecture parameter is not written to configuration file.")
+        section_name = get_file_section_name(self.section_key, self.section_label)
+        try:
+            config_parser.remove_option(section_name, self.key)
+        except NoSectionError:
+            pass
+
     @staticmethod
     def get_master_instance_type_architecture(cluster_section):
         """Compute cluster's 'Architecture' CFN parameter based on its master server instance type."""
@@ -967,7 +985,7 @@ class SettingsParam(Param):
                 if "," in self.value:
                     self.pcluster_config.error(
                         "The value of '{0}' parameter is invalid. "
-                        "It can only contains a single {1} section label.".format(self.key, self.referred_section_key)
+                        "It can only contain a single {1} section label.".format(self.key, self.referred_section_key)
                     )
                 else:
                     # Calls the "from_file" of the Section
@@ -1004,7 +1022,7 @@ class SettingsParam(Param):
             if "," in self.value:
                 self.pcluster_config.error(
                     "The default value of '{0}' parameter is invalid. "
-                    "It can only contains a single {1} section label.".format(self.key, self.referred_section_key)
+                    "It can only contain a single {1} section label.".format(self.key, self.referred_section_key)
                 )
             else:
                 # initialize related section with default values
